@@ -720,6 +720,7 @@ def live_generate(
     if isinstance(inputs, list) or inputs.shape[0] > 1:
         raise NotImplementedError('We currently only support live generation '
                                   'for one input prompt at a time.')
+    inputs = inputs.to(model.device)
 
     # 1. Set generation parameters if not already defined
     bos_token_id = (bos_token_id if bos_token_id is not None
@@ -1040,6 +1041,7 @@ def generate(
         prompt,
         out_dir=None,
         mode_pre='a',
+        max_new_tokens=50,
         repetition_penalty=1.2,
         early_stopping=False,
         do_sample=True,
@@ -1104,7 +1106,8 @@ def generate(
         early_stopping=early_stopping,
         do_sample=do_sample,
         temperature=temperature,
-        top_p=top_p
+        top_p=top_p,
+        max_new_tokens=max_new_tokens
     )
 
     # Make it easier to provide words to skip/include. Lets us pass in lists
